@@ -18,7 +18,7 @@ class UserRoleManager(models.Manager):
 class UserRole(models.Model):
     user = models.ForeignKey(User, on_delete=models.CASCADE)
     volume = models.ForeignKey(Volume, on_delete=models.CASCADE)
-    opertations = models.ManyToManyField(Action, blank=True)
+    actions = models.ManyToManyField(Action, blank=True)
     creation_date = models.DateTimeField(default=timezone.now)
 
     userroles = UserRoleManager()
@@ -35,6 +35,6 @@ class UserRole(models.Model):
         """Return the volum."""
         return self.volume
 
-    def getOperations(self):
+    def getActions(self):
         """Return the operations."""
-        return self.opertations
\ No newline at end of file
+        return self.actions
\ No newline at end of file
