@@ -30,12 +30,6 @@ function correctActionBtn(){
     // GETTING LIST OF ALL BUTTON
     let action_btn = document.getElementsByName('action-btn');
 
-    // GETTING COLOR CLASSES
-    const color_classes = {
-        'download': 'btn-primary',
-        'delete': 'btn-danger',
-        'upload': 'btn-warning',
-    };
     for (let btn of action_btn){
         // GETING ACTION NAME
         action = btn.id;
@@ -45,12 +39,13 @@ function correctActionBtn(){
         btn.innerHTML = action_str;
 
         // CHAINING COLOR
-        btn_color = color_classes[action];
-        if (btn_color != undefined){
-            btn.className += ` ${btn_color}`;
-            btn.title = `${action_str} data`
+        btn_detail = action_btn_detail[action];
+        if (btn_detail != undefined){
+            btn.className += ` ${btn_detail['color']}`;
+            btn.title = `${action_str} data`;
+            btn.disabled = btn_detail['disabled'];
         }else {
-            btn.title = 'Action color not defined'
+            btn.title = 'Action color not defined';
         }
     }
 }
\ No newline at end of file
