@@ -1,13 +1,12 @@
-from django.http import FileResponse
-import os
-import shutil
 from django import http
-from django.views.generic.base import TemplateView
-from django.urls import reverse
+from django.http import FileResponse
 from django.shortcuts import render
+from django.urls import reverse
+from django.views.generic.base import TemplateView
 
-from .operations.location import LocationOperations
 from .operations.explorer import ExplorerOperations
+from .operations.location import LocationOperations
+from .operations.action import ActionOperations
 
 class Explorer(TemplateView):
     template_name = 'explorer/index.html'
@@ -79,12 +78,15 @@ class Explorer(TemplateView):
         # GETTING LOCATION OBJECT
         lo = LocationOperations(volume_info, location_path)
 
-        # GETTING LOATION REATED DATA
+        # GETTING LOCATION RELATED DATA
         data_list = lo.getData() # Getting location file and dir data.
         path_list = xo.getCheckedFilePath(data_list) # Getting page data.
 
         # PERFORMING ACTION
-        file_path = lo.performAction(path_list, xo.getAction())
+        ao = ActionOperations(volume_info, location_path)
+        file_path = ao.performAction(xo.getAction(), path_list, xo.getFileData())
+        if ao.getMessage():
+            return self._render_warning(request, xo.getMessage())
 
         if file_path: # Download case
             return FileResponse(open(file_path, 'rb'), as_attachment=True)
@@ -102,6 +104,10 @@ class Explorer(TemplateView):
     def _render_warning(self, request, message):
         """Rendered warning template"""
         return render(request, 'explorer/warning.html', {'message': message})
+    
+    def _render_error(self, request, message):
+        """Rendered error template"""
+        return render(request, 'explorer/error.html', {'message': message})
 
     def _render_file(self, request, file_path):
         """Return the file render response."""
